@@ -19,6 +19,8 @@ class APIRequest:
             self.method = requests.post
         elif method == 'DELETE':
             self.method = requests.delete
+        elif method == 'PATCH':
+            self.method = requests.patch
         else:
             raise ValueError('Method must be either GET, POST, or DELETE')
 
